@@ -122,7 +122,10 @@ def replace_spaces(name, path, mode):
     """ if mode == 0: ' ' -> '_'
         if mode == 1: '_' -> ' '
         if mode == 2: '_' -> '.'
-        if mode == 3: '.' -> ' ' """
+        if mode == 3: '.' -> ' '
+        if mode == 4: ' ' -> '-'
+        if mode == 5: '-' -> ' ' """
+        
     name = unicode(name)
     path = unicode(path)
     
@@ -134,6 +137,10 @@ def replace_spaces(name, path, mode):
         newname = name.replace(' ', '.')
     elif mode == 3:
         newname = name.replace('.', ' ')
+    elif mode == 4:
+        newname = name.replace(' ', '-')
+    elif mode == 5:
+        newname = name.replace('-', ' ')
         
     newpath = get_new_path(newname, path)
     return unicode(newname), unicode(newpath)
@@ -218,6 +225,22 @@ def replace_accents(name, path):
     newname = newname.replace('Ü', 'U')
     newname = newname.replace('Û', 'U')
     
+    """ Czech language accents replacement """
+    newname = newname.replace('ě', 'e')
+    newname = newname.replace('š', 's')
+    newname = newname.replace('č', 'c')
+    newname = newname.replace('ř', 'r')
+    newname = newname.replace('ž', 'z')
+    newname = newname.replace('ý', 'y')
+    newname = newname.replace('ů', 'u')
+    newname = newname.replace('Ě', 'E')
+    newname = newname.replace('Š', 'S')
+    newname = newname.replace('Č', 'C')
+    newname = newname.replace('Ř', 'R')
+    newname = newname.replace('Ž', 'Z')
+    newname = newname.replace('Ý', 'Y')
+    newname = newname.replace('Ů', 'U')
+    
     newpath = get_new_path(newname, path)
     return unicode(newname), unicode(newpath)
 
